#include <Wire.h>
#include <LiquidCrystal_I2C.h>
#include <virtuabotixRTC.h>

#define DRIVER_SPEED 5
#define PAUSE 2

int distance; // Variable to store the distance
int drive_time; // Variable to store the driving time
int remaining_time; // Variable to store the remaining time

String message = "The distance is: ";

int buzzPin = 3;

// Set the LCD address to 0x27 for a 20 chars and 4 lines display
LiquidCrystal_I2C lcd(0x27, 20, 4);

// Creation of the Real Time Clock Object
virtuabotixRTC myRTC(6, 7, 8);

void setup() {
  // put your setup code here, to run once:
  Serial.begin(9600);

  // Initialize the LCD
  lcd.begin();

  lcd.clear();

  // Turn on the light
  lcd.backlight();

  // Set the current date and time
  myRTC.setDS1302Time(25, 17, 10, 4, 6, 3, 2021);

  distance = Serial.parseInt();

  pinMode(buzzPin, OUTPUT);
}

void loop() {
  // put your main code here, to run repeatedly:

    while (Serial.available() == 0) {
      
    }

    // Update the time
    myRTC.updateTime();

    // Print the current date and time
    lcd.setCursor(0, 0);
    lcd.print(myRTC.dayofmonth);
    lcd.print("/");
    lcd.print(myRTC.month);
    lcd.print("/");
    lcd.print(myRTC.year);
    lcd.print(" ");
    lcd.print(myRTC.hours);
    lcd.print(":");
    lcd.print(myRTC.minutes);
    lcd.print(":");
    lcd.print(myRTC.seconds);

    Serial.print(message);
    Serial.println(distance);

    // Print the distance to the LCD screen on the first row
    lcd.setCursor(0, 1);
    lcd.print("Distance: ");
    lcd.print(distance);
    lcd.print("km");

    // Calculate the driving time
    drive_time = (distance * 1000) / (DRIVER_SPEED * 1000 / 3600);

    // Print the driving time to the LCD screen on the second row
    lcd.setCursor(0, 2);
    lcd.print("Time: ");
    lcd.print(drive_time / 3600);
    lcd.print("h");

    // Calculate the remaining time
    remaining_time = PAUSE - (drive_time / 3600);

    // Print the remaining time to the LCD screen of the third row
    lcd.setCursor(0, 3);
    lcd.print("Remaining hours: ");
    lcd.print(remaining_time);
    lcd.print("h");

    // Implement the logic of the buzzer
    if ((PAUSE * 3600 - remaining_time * 3600) == 300) {
      tone(buzzPin, 300, 100);
    }

    delay(500000);
}
